#[non_exhaustive]pub struct SourceSeekAnchor {
pub segment_start: Duration,
pub segment_end: Option<Duration>,
pub segment_index: Option<u32>,
pub variant_index: Option<usize>,
pub byte_offset: u64,
}Expand description
Time-first seek anchor resolved by a segmented source.
Represents a deterministic mapping from target playback time to a byte position and segment context inside the source.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.segment_start: Durationsegment_end: Option<Duration>segment_index: Option<u32>variant_index: Option<usize>byte_offset: u64Implementations
Sourceimpl SourceSeekAnchor
impl SourceSeekAnchor
Sourcepub fn builder() -> SourceSeekAnchorBuilder
pub fn builder() -> SourceSeekAnchorBuilder
Create an instance of SourceSeekAnchor using the builder syntax